@@ -30,7 +30,7 @@ sub regexes
                 my $re     = ("a?" x $n) . ("a" x $n);
                 my $string = "a" x $n;
 
-                print STDERR " - $subtest...\n" if $options->{verbose} > 2;
+                print STDERR "#  - $subtest...\n" if $options->{verbose} > 2;
                 my $t = timeit $count, sub { $string =~ /$re/ };
                 $results{$subtest} = {
                                       Benchmark => $t,
@@ -59,7 +59,7 @@ sub regexes
                 my $string = (("a" x $length) . " ") x 5;
                 chop $string;
 
-                print STDERR " - $subtest...\n" if $options->{verbose} > 2;
+                print STDERR "#  - $subtest...\n" if $options->{verbose} > 2;
                 my $t = timeit $count, sub { $string =~ /$re/ };
                 $results{$subtest} = {
                                       Benchmark => $t,
@@ -77,7 +77,7 @@ sub regexes
                 my $string = ( ("a" x $length) . " " ) x 5;
                 chop $string;
 
-                print STDERR " - $subtest...\n" if $options->{verbose} > 2;
+                print STDERR "#  - $subtest...\n" if $options->{verbose} > 2;
                 my $t = timeit $count, sub { $string =~ /$re/ };
                 $results{$subtest} = {
                                       Benchmark => $t,
